# MuProcDurham

[![tests](https://github.com/ComputationalMusicologyDurham/MuProcDurham/actions/workflows/tests.yml/badge.svg)](https://github.com/ComputationalMusicologyDurham/MuProcDurham/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/ComputationalMusicologyDurham/MuProcDurham/graph/badge.svg?token=POW37LFZGQ)](https://codecov.io/gh/ComputationalMusicologyDurham/MuProcDurham)

![build](https://github.com/ComputationalMusicologyDurham/MuProcDurham/workflows/build/badge.svg)
[![PyPI version](https://badge.fury.io/py/muprocdurham.svg)](https://badge.fury.io/py/muprocdurham)

[![doc](https://github.com/ComputationalMusicologyDurham/MuProcDurham/actions/workflows/doc.yml/badge.svg)](https://computationalmusicologydurham.github.io/MuProcDurham/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

Python package for the Music Processing lecture and practicals at Durham University.
